@@ -35,15 +35,20 @@ class ImageDescription:
 
     def predict_caption(self):
         new_images = []
+        model = self.model.to(self.device)
+        feature_extractor = self.feature_extractor
+        tokenizer = self.tokenizer
+        gen_kwargs = self.gen_kwargs
+
         for image in self.formatted_images:
             if image.mode != "RGB":
                 image = image.convert(mode="RGB")
             new_images.append(image)
         print("Predicting Image Description")
-        pixel_values = self.feature_extractor(images=new_images, return_tensors="pt").pixel_values
+        pixel_values = feature_extractor(images=new_images, return_tensors="pt").pixel_values
         pixel_values = pixel_values.to(self.device)
-        output_ids = self.model.generate(pixel_values, **self.gen_kwargs)
-        preds = self.tokenizer.batch_decode(output_ids, skip_special_tokens=True)
+        output_ids = model.generate(pixel_values, **gen_kwargs)
+        preds = tokenizer.batch_decode(output_ids, skip_special_tokens=True)
         preds = [pred.strip() for pred in preds]
         print("Predicting Image Description - Done!")
         return preds
